Parameters — miml documentation

Skip to main content
`Ctrl`+`K`

# Parameters

class miml.transformation.mimlTOml.geometric.GeometricTransformation

  Bases: `MIMLtoMLTransformation`

  Class that performs a geometric transformation to convert a MIMLDataset class to numpy ndarray.

  transform_bag(bag: Bag) → Bag

    Transform a bag to a multilabel instance

    # Parameters

    bagBag

      Bag to be transformed to multilabel instance

    # Returns

    featuresndarray of shape (n_features)

      Numpy array with feature values

    labelsndarray of shape (n_labels)

      Numpy array with label values

  transform_dataset(dataset: MIMLDataset) → MIMLDataset

    Transform the dataset to multilabel dataset converting each bag into a single instance being the value of each attribute the geometric center of the instances in the bag.

    # Returns